package X6FRs_4.IMuAHx_6.EuDEkJe_12;

import android.view.View;
/* compiled from: NestedScrollingParent.java */
/* loaded from: classes.dex */
public interface YghfZG_14 {
    boolean onNestedFling(View view, float f, float f2, boolean z);

    boolean onNestedPreFling(View view, float f, float f2);

    void onNestedPreScroll(View view, int i, int i2, int[] iArr);

    void onNestedScroll(View view, int i, int i2, int i3, int i4);

    void onNestedScrollAccepted(View view, View view2, int i);

    boolean onStartNestedScroll(View view, View view2, int i);

    void onStopNestedScroll(View view);
}
