package X6FRs_4.IMuAHx_6.EuDEkJe_12;

import android.os.Build;
import android.util.Log;
import android.view.View;
import android.view.ViewParent;
import android.view.accessibility.AccessibilityEvent;
/* compiled from: ViewParentCompat.java */
/* loaded from: classes.dex */
public final class SI64pbG_23 {
    @Deprecated
    public static boolean KQgRr5e_0(ViewParent viewParent, View view, AccessibilityEvent accessibilityEvent) {
        return viewParent.requestSendAccessibilityEvent(view, accessibilityEvent);
    }

    /* renamed from: KQgRr5e_0  reason: collision with other method in class */
    public static boolean m244KQgRr5e_0(ViewParent viewParent, View view, View view2, int i, int i2) {
        if (viewParent instanceof EuDEkJe_12) {
            return ((EuDEkJe_12) viewParent).onStartNestedScroll(view, view2, i, i2);
        }
        if (i2 == 0) {
            if (Build.VERSION.SDK_INT >= 21) {
                try {
                    return viewParent.onStartNestedScroll(view, view2, i);
                } catch (AbstractMethodError e) {
                    Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onStartNestedScroll", e);
                    return false;
                }
            } else if (viewParent instanceof YghfZG_14) {
                return ((YghfZG_14) viewParent).onStartNestedScroll(view, view2, i);
            } else {
                return false;
            }
        }
        return false;
    }

    public static void KQgRr5e_0(ViewParent viewParent, View view, View view2, int i, int i2) {
        if (viewParent instanceof EuDEkJe_12) {
            ((EuDEkJe_12) viewParent).onNestedScrollAccepted(view, view2, i, i2);
        } else if (i2 == 0) {
            if (Build.VERSION.SDK_INT >= 21) {
                try {
                    viewParent.onNestedScrollAccepted(view, view2, i);
                } catch (AbstractMethodError e) {
                    Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onNestedScrollAccepted", e);
                }
            } else if (viewParent instanceof YghfZG_14) {
                ((YghfZG_14) viewParent).onNestedScrollAccepted(view, view2, i);
            }
        }
    }

    public static void KQgRr5e_0(ViewParent viewParent, View view, int i) {
        if (viewParent instanceof EuDEkJe_12) {
            ((EuDEkJe_12) viewParent).onStopNestedScroll(view, i);
        } else if (i == 0) {
            if (Build.VERSION.SDK_INT >= 21) {
                try {
                    viewParent.onStopNestedScroll(view);
                } catch (AbstractMethodError e) {
                    Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onStopNestedScroll", e);
                }
            } else if (viewParent instanceof YghfZG_14) {
                ((YghfZG_14) viewParent).onStopNestedScroll(view);
            }
        }
    }

    public static void KQgRr5e_0(ViewParent viewParent, View view, int i, int i2, int i3, int i4, int i5, int[] iArr) {
        if (viewParent instanceof WwEq_13) {
            ((WwEq_13) viewParent).KQgRr5e_0(view, i, i2, i3, i4, i5, iArr);
            return;
        }
        iArr[0] = iArr[0] + i3;
        iArr[1] = iArr[1] + i4;
        if (viewParent instanceof EuDEkJe_12) {
            ((EuDEkJe_12) viewParent).onNestedScroll(view, i, i2, i3, i4, i5);
        } else if (i5 == 0) {
            if (Build.VERSION.SDK_INT >= 21) {
                try {
                    viewParent.onNestedScroll(view, i, i2, i3, i4);
                } catch (AbstractMethodError e) {
                    Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onNestedScroll", e);
                }
            } else if (viewParent instanceof YghfZG_14) {
                ((YghfZG_14) viewParent).onNestedScroll(view, i, i2, i3, i4);
            }
        }
    }

    public static void KQgRr5e_0(ViewParent viewParent, View view, int i, int i2, int[] iArr, int i3) {
        if (viewParent instanceof EuDEkJe_12) {
            ((EuDEkJe_12) viewParent).onNestedPreScroll(view, i, i2, iArr, i3);
        } else if (i3 == 0) {
            if (Build.VERSION.SDK_INT >= 21) {
                try {
                    viewParent.onNestedPreScroll(view, i, i2, iArr);
                } catch (AbstractMethodError e) {
                    Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onNestedPreScroll", e);
                }
            } else if (viewParent instanceof YghfZG_14) {
                ((YghfZG_14) viewParent).onNestedPreScroll(view, i, i2, iArr);
            }
        }
    }

    public static boolean KQgRr5e_0(ViewParent viewParent, View view, float f, float f2, boolean z) {
        if (Build.VERSION.SDK_INT >= 21) {
            try {
                return viewParent.onNestedFling(view, f, f2, z);
            } catch (AbstractMethodError e) {
                Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onNestedFling", e);
                return false;
            }
        } else if (viewParent instanceof YghfZG_14) {
            return ((YghfZG_14) viewParent).onNestedFling(view, f, f2, z);
        } else {
            return false;
        }
    }

    public static boolean KQgRr5e_0(ViewParent viewParent, View view, float f, float f2) {
        if (Build.VERSION.SDK_INT >= 21) {
            try {
                return viewParent.onNestedPreFling(view, f, f2);
            } catch (AbstractMethodError e) {
                Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onNestedPreFling", e);
                return false;
            }
        } else if (viewParent instanceof YghfZG_14) {
            return ((YghfZG_14) viewParent).onNestedPreFling(view, f, f2);
        } else {
            return false;
        }
    }
}
